#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-LrybVZzinZu2ej1qHnocI4
key:                  warp-quic-0.0.0-LrybVZzinZu2ej1qHnocI4
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  d82bc091e54d04f3ecdcd4568262fcf1
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-LrybVZzinZu2ej1qHnocI4
depends:
    base-4.18.2.1 bytestring-0.11.5.3 http3-0.0.9-Z3vCGGsMRdEQotft1ctKc
    quic-0.1.28-HMiL1WcdK5GArXo2syz0Cx tls-2.0.6-L1CXpmp4taTKKTqOC9HsCU
    wai-3.2.4-AbeRAt4VbX71hUAZJ2jn1Q warp-3.4.0-BDJaJCcpYjEE7vdhVdOwwq

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

